@@ -135,7 +135,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_CONNECTED_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_ENABLED_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_MASTER);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_POLARITY);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_INTERVAL);
@@ -179,8 +178,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_BUS_RATE);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY);
     MAKE_SIGNAL(NV_CTRL_ASSOCIATED_DISPLAY_DEVICES);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SLAVES);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_MASTERABLE);
     MAKE_SIGNAL(NV_CTRL_PROBE_DISPLAYS);
     MAKE_SIGNAL(NV_CTRL_REFRESH_RATE);
     MAKE_SIGNAL(NV_CTRL_INITIAL_PIXMAP_PLACEMENT);
@@ -211,7 +208,6 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_NOTEBOOK_DISPLAY_CHANGE_LID_EVENT);
     MAKE_SIGNAL(NV_CTRL_MODE_SET_EVENT);
     MAKE_SIGNAL(NV_CTRL_OPENGL_AA_LINE_GAMMA_VALUE);
-    MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SLAVEABLE);
     MAKE_SIGNAL(NV_CTRL_DISPLAYPORT_LINK_RATE);
     MAKE_SIGNAL(NV_CTRL_STEREO_EYES_EXCHANGE);
     MAKE_SIGNAL(NV_CTRL_NO_SCANOUT);
@@ -271,7 +267,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GPU_DOUBLE_PRECISION_BOOST_REBOOT);
     MAKE_SIGNAL(NV_CTRL_DPY_HDMI_3D);
     MAKE_SIGNAL(NV_CTRL_BASE_MOSAIC);
-    MAKE_SIGNAL(NV_CTRL_MULTIGPU_MASTER_POSSIBLE);
+    MAKE_SIGNAL(NV_CTRL_MULTIGPU_PRIMARY_POSSIBLE);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_DEFAULT_MODE);
     MAKE_SIGNAL(NV_CTRL_XV_SYNC_TO_DISPLAY_ID);
     MAKE_SIGNAL(NV_CTRL_CURRENT_XV_SYNC_TO_DISPLAY_ID);
@@ -310,7 +306,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_PLATFORM_POWER_MODE
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_PLATFORM_CURRENT_POWER_MODE
 #warning "There are attributes that do not emit signals!"
 #endif
 
